pub fn step(
config: &ModelConfig,
req: &AnalyzeRequest,
) -> Result<Step, ModelError>Expand description
One turn of the tool loop: either the final answer, or a tool to run.
pub fn step(
config: &ModelConfig,
req: &AnalyzeRequest,
) -> Result<Step, ModelError>One turn of the tool loop: either the final answer, or a tool to run.